BBox

Struct BBox 

pub struct BBox { /* private fields */ }
A Bounding box

Implementations

Source

impl BBox

pub fn new(top: f32, left: f32, bottom: f32, right: f32) -> Option<BBox>

Construct a new BBox from the given max and min latitude and longitude. Returns None if the lat or lon is invalid, e.g. a lon of 200

pub fn new_from_points(topleft: &LatLon, bottomright: &LatLon) -> BBox

Given two points, return the bounding box specified by those 2 points

pub fn new_from_tile(tile: &Tile) -> Self

Construct a BBox from a tile

pub fn contains_point(&self, point: &LatLon) -> bool

Return true iff this point is in this bbox

pub fn overlaps_bbox(&self, other: &BBox) -> bool

Returns true iff this bbox and other share at least one point

pub fn tiles(&self) -> BBoxTilesIterator<'_>

Iterate over all the tiles from z0 onwards that this bbox is in

pub fn metatiles(&self, scale: u8) -> MetatilesIterator

Iterate over all the metatiles from z0 onwards that this bbox is in

pub fn top(&self) -> f32

Return the top value of this bbox

pub fn bottom(&self) -> f32

Return the bottom value of this bbox

pub fn left(&self) -> f32

Return the left value of this bbox

pub fn right(&self) -> f32

Return the right value of this bbox

pub fn tiles_for_zoom(&self, zoom: u8) -> impl Iterator<Item = Tile>

For this zoom level, return all the tiles that cover this bbox

pub fn centre_point(&self) -> LatLon

Returns the LatLon for the centre of this bbox

pub fn center_point(&self) -> LatLon

Returns the LatLon for the centre of this bbox

pub fn nw_corner(&self) -> LatLon

Returns the LatLon of the top left, i.e. north west corner, of this bbot

pub fn ne_corner(&self) -> LatLon

Returns the LatLon of the top right, i.e. north east corner, of this bbox

pub fn sw_corner(&self) -> LatLon

Returns the LatLon of the bottom left, i.e. south west corner, of this bbox

pub fn se_corner(&self) -> LatLon

Returns the LatLon of the bottom right, i.e. south east corner, of this bbox.