ModTileMetatile

Struct ModTileMetatile 

pub struct ModTileMetatile { /* private fields */ }
Metatiles as found by mod_tile, always 8x8

Implementations

Source

impl ModTileMetatile

pub fn new(zoom: u8, x: u32, y: u32) -> Option<Self>

pub fn path<T: Display>(&self, ext: T) -> String

Returns the mod_tile path for storing this metatile

pub fn x(&self) -> u32

X value of this metatile

pub fn y(&self) -> u32

Y value of metatile

pub fn zoom(&self) -> u8

Zoom value of metatile

pub fn size(self) -> u8

What is the width or height of this metatile. For small zoom numbers (e.g. z1), there will not be the full scale tiles across.

Methods from Deref<Target = Metatile>

pub fn scale(&self) -> u8

pub fn zoom(&self) -> u8

pub fn size(&self) -> u8

What is the width or height of this metatile. For small zoom numbers (e.g. z1), there will not be the full scale tiles across.

pub fn centre_point(&self) -> LatLon

Returns the LatLon for the centre of this metatile.

pub fn center_point(&self) -> LatLon

Returns the LatLon for the centre of this metatile.

pub fn nw_corner(&self) -> LatLon

Returns the LatLon of the top left, i.e. north west corner, of this metatile.

pub fn ne_corner(&self) -> LatLon

Returns the LatLon of the top right, i.e. north east corner, of this metatile.

pub fn sw_corner(&self) -> LatLon

Returns the LatLon of the bottom left, i.e. south west corner, of this metatile.

pub fn se_corner(&self) -> LatLon

Returns the LatLon of the bottom right, i.e. south east corner, of this metatile.

pub fn x(&self) -> u32

X value of this metatile

pub fn y(&self) -> u32

Y value of metatile

pub fn tiles(&self) -> Vec<Tile>